﻿Imports System.IO
Imports System.Net
Imports System.Net.Http
Imports System.Web.Http
Imports Newtonsoft.Json
Imports Syncfusion.EJ2.PdfViewer

Namespace Controllers
    <Cors.EnableCors("*", "*", "*")>
    Public Class PdfViewerController
        Inherits ApiController

        <HttpPost>
        Public Function Load(ByVal jsonObject As Dictionary(Of String, String)) As Object
            Dim pdfviewer As PdfRenderer = New PdfRenderer()
            Dim stream As MemoryStream = New MemoryStream()
            Dim jsonResult As Object = New Object()

            If jsonObject IsNot Nothing AndAlso jsonObject.ContainsKey("document") Then

                If Boolean.Parse(jsonObject("isFileName")) Then
                    Dim documentPath As String = GetDocumentPath(jsonObject("document"))

                    If Not String.IsNullOrEmpty(documentPath) Then
                        Dim bytes As Byte() = System.IO.File.ReadAllBytes(documentPath)
                        stream = New MemoryStream(bytes)
                    Else
                        Return (jsonObject("document") & " is not found")
                    End If
                Else
                    Dim bytes As Byte() = Convert.FromBase64String(jsonObject("document"))
                    stream = New MemoryStream(bytes)
                End If
            End If

            jsonResult = pdfviewer.Load(stream, jsonObject)
            Return (JsonConvert.SerializeObject(jsonResult))
        End Function

        <HttpPost>
        Public Function RenderPdfPages(ByVal jsonObject As Dictionary(Of String, String)) As Object
            Dim pdfviewer As PdfRenderer = New PdfRenderer()
            Dim jsonResult As Object = pdfviewer.GetPage(jsonObject)
            Return (JsonConvert.SerializeObject(jsonResult))
        End Function

        <HttpPost>
        Public Function Bookmarks(ByVal jsonObject As Dictionary(Of String, String)) As Object
            Dim pdfviewer As PdfRenderer = New PdfRenderer()
            Dim jsonResult = pdfviewer.GetBookmarks(jsonObject)
            Return (JsonConvert.SerializeObject(jsonResult))
        End Function

        <HttpPost>
        Public Function RenderThumbnailImages(ByVal jsonObject As Dictionary(Of String, String)) As Object
            Dim pdfviewer As PdfRenderer = New PdfRenderer()
            Dim result As Object = pdfviewer.GetThumbnailImages(jsonObject)
            Return (JsonConvert.SerializeObject(result))
        End Function

        <HttpPost>
        Public Function PrintImages(ByVal jsonObject As Dictionary(Of String, String)) As Object
            Dim pdfviewer As PdfRenderer = New PdfRenderer()
            Dim pageImage As Object = pdfviewer.GetPrintImage(jsonObject)
            Return (pageImage)
        End Function

        <HttpPost>
        Public Function Download(ByVal jsonObject As Dictionary(Of String, String)) As HttpResponseMessage
            Dim pdfviewer As PdfRenderer = New PdfRenderer()
            Dim documentBase As String = pdfviewer.GetDocumentAsBase64(jsonObject)
            Return (GetPlainText(documentBase))
        End Function

        <HttpPost>
        Public Function Unload(ByVal jsonObject As Dictionary(Of String, String)) As Object
            Dim pdfviewer As PdfRenderer = New PdfRenderer()
            pdfviewer.ClearCache(jsonObject)
            Return ("Document cache is cleared")
        End Function

        Private Function GetPlainText(ByVal pageImage As String) As HttpResponseMessage
            Dim responseText = New HttpResponseMessage(HttpStatusCode.OK)
            responseText.Content = New StringContent(pageImage, System.Text.Encoding.UTF8, "text/plain")
            Return responseText
        End Function

        Private Function GetDocumentPath(ByVal document As String) As String
            Dim documentPath As String = String.Empty

            If Not System.IO.File.Exists(document) Then
                Dim path = HttpContext.Current.Request.PhysicalApplicationPath
                If System.IO.File.Exists(path & "App_Data\Data\" & document) Then documentPath = path & "App_Data\Data\" & document
            Else
                documentPath = document
            End If

            Return documentPath
        End Function
    End Class
End Namespace